@@ -12,7 +12,7 @@ use JSON::XS ();
 use YAML::XS ();
 use POSIX ();
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 $Carp::Internal{ (__PACKAGE__) }++;
 
@@ -21,9 +21,23 @@ sub _location {
 }
 
 sub import {
-    my ( $self, $lib_dir, $location ) = @_;
-    my ( $root_dir, $config_file ) = _find_root_dir( $location || _location() );
-    unshift( @INC, $root_dir . '/' . ( $lib_dir || 'lib' ) ) if ( -f $config_file );
+    my $self = shift;
+
+    my ( $root_dir, $config_file, $location, @libs );
+    for (
+        ( @_ > 1 )  ? ( $_[0], $_[-1], _location() ) :
+        ( @_ == 1 ) ? ( $_[0], _location() )         : _location()
+    ) {
+        ( $root_dir, $config_file ) = _find_root_dir($_);
+        if ( -f $config_file ) {
+            $location = substr( $config_file, length($root_dir) + 1 );
+            @libs     = grep { $location ne $_ } @_;
+            last;
+        }
+    }
+
+    unshift( @INC, $root_dir . "/$_" ) for ( @libs || 'lib' );
+    eval { $self->new($location) };
     return;
 }
 
@@ -122,6 +136,10 @@ sub _location_fetch {
         _location_fetch( $box, $user, $env, $conf, \$optional_include, $location, @source_path );
     }
 
+    if ( $conf->{libs} and ref $conf->{libs} eq 'ARRAY' ) {
+        unshift( @INC, $root_dir . "/$_" ) for ( @{ $conf->{libs} } );
+    }
+
     return;
 }
 
@@ -278,7 +296,7 @@ Config::App - Cascading merged application configuration
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Config-App.svg)](https://travis-ci.org/gryphonshafer/Config-App)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Config-App/badge.png)](https://coveralls.io/r/gryphonshafer/Config-App)
@@ -550,10 +568,23 @@ a directory alternative from "lib" in the use line.
     use Config::App;        # add "root_dir/lib"  to @INC
     use Config::App 'lib2'; # add "root_dir/lib2" to @INC
 
-To skip this behavior, do this:
+You can also supply multiple library directories and a specific configuration
+file location relative to your project's root directory. If you specify a
+relative configuration file location, it must be either the first or last value
+provided.
+
+    use Config::App qw( lib lib2 config.yaml );
+
+To skip all this behavior, do this:
 
     use Config::App ();
 
+=head2 Injection via configuration file setting
+
+You can also inject relative library paths by using the "libs" keyword in the
+base of the configuration, similar to "include". The "libs" keyword expects an
+arrayref of relative paths.
+
 =head1 DIRECT DEPENDENCIES
 
 L<URI>, L<LWP::UserAgent>, L<Carp>, L<FindBin>, L<JSON::XS>, L<YAML::XS>, L<POSIX>.
